RegisterStateRef

Struct RegisterStateRef 

pub struct RegisterStateRef<'a>(/* private fields */);
A reference to the register state saved when an exception happened.

Implementations

Source

impl RegisterStateRef<'_>

pub unsafe fn get_mut(&mut self) -> &mut RegisterState

Returns a mutable reference to the register state.

Safety

Any changes made to the saved register state made via this reference must not cause undefined behaviour when returning from the exception.

Exactly what this means depends on the exception and the context in which it happened, but for example changing the ELR to point to an invalid or unexpected location, or changing some general-purpose register value which the code doesn’t expect to change could cause undefined behaviour.